package ActiveState::Delta;

use strict;

our $VERSION = '5.500';

use XSLoader();
XSLoader::load(__PACKAGE__, $VERSION);

use base qw(Exporter);
our @EXPORT_OK = qw(diff patch);

sub diff {
    require ActiveState::Delta::Algo::BPatch;
    goto &ActiveState::Delta::Algo::BPatch::diff;
}

1;

=head1 NAME

ActiveState::Delta - binary diffs and patches

=head1 SYNOPSIS

    use ActiveState::Delta qw(patch diff);
    
    # Apply a diff
    $post = patch($ante, $delta);
    
    # Generate a diff
    # NOTE: requires ActiveState::Delta::Algo
    $delta = diff($ante, $post);

=head1 DESCRIPTION

ActiveState::Delta uses a simple algorithm to calculate deltas between two
binary strings. The checksums of F<$ante>, F<$delta>, and F<$post> are all
stored in F<$delta>, so that errors can be detected.

Generating Deltas requires the ActiveState-Delta-Algo package to be installed.

=head2 Functions

The following functions can be exported:

=over

=item diff()

 $delta = diff($ante, $post)

Generates and returns the C<$delta> between the buffers C<$ante> and C<$post>.

Requires that the ActiveState::Delta::BPatch module is installed.

=item patch()

 $post = patch($ante, $delta)

Generates and returns C<$post> by appying the C<$delta> to C<$ante>. This
method croaks if C<$delta> is corrupted; if C<$ante>'s checksum does not match
the one embedded in C<$delta>; or if the resulting C<$post>'s checksum is not
valid (the latter error indicates a bug in the ActiveState::Delta library).

=back

=head1 AUTHOR

Copyright (C) 2004, Sophos Canada.  All Rights Reserved.

=cut
